trata_notes_client_sdk library

Classes

ActionItemCreate
ActionItemCreate
ActionItemCreateBuilder
ActionItemResponse
ActionItemResponse
ActionItemResponseBuilder
ApiKeyAuthInterceptor
BasicAuthInfo
BasicAuthInterceptor
BearerAuthInterceptor
CallCancelRequest
Request schema for cancelling a call
CallCancelRequestBuilder
CallCancelResponse
Response schema for call cancellation
CallCancelResponseBuilder
CallListResponse
Response schema for call list
CallListResponseBuilder
CallPriceResponse
Response schema for call pricing
CallPriceResponseBuilder
CallRecordingResponse
CallRecordingResponse
CallRecordingResponseBuilder
CallRecordingUploadResponse
CallRecordingUploadResponse
CallRecordingUploadResponseBuilder
CallsApi
CallStartRequest
Request schema for starting a call
CallStartRequestBuilder
CallStartResponse
Response schema for call start
CallStartResponseBuilder
CallStatus
CallStatusMixin
Optionally, enum_class can generate a mixin to go with your enum for use with Angular. It exposes your enum constants as getters. So, if you mix it in to your Dart component class, the values become available to the corresponding Angular template.
CallStatusResponse
Response schema for call status
CallStatusResponseBuilder
ContactCreate
Schema for creating a contact
ContactCreateBuilder
ContactListResponse
Schema for contact list response
ContactListResponseBuilder
ContactResponse
Schema for contact response
ContactResponseBuilder
ContactsApi
ContactSyncRequest
Schema for contact sync request
ContactSyncRequestBuilder
ContactSyncResponse
Schema for contact sync response
ContactSyncResponseBuilder
ContactUpdate
Schema for updating a contact
ContactUpdateBuilder
CreditsApi
CreditsHistoryEntry
CreditsHistoryEntry
CreditsHistoryEntryBuilder
CreditsHistoryResponse
CreditsHistoryResponse
CreditsHistoryResponseBuilder
CreditsResponse
CreditsResponse
CreditsResponseBuilder
DailyWebhooksApi
Date
A gregorian calendar date generated by OpenAPI generator to differentiate between DateTime and Date formats.
DefaultApi
FilesApi
HTTPValidationError
HTTPValidationError
HTTPValidationErrorBuilder
LocationInner
LocationInner
LocationInnerBuilder
OAuthInterceptor
PaymentIntentRequest
Request schema for creating a payment intent
PaymentIntentRequestBuilder
PaymentIntentResponse
Response schema for payment intent
PaymentIntentResponseBuilder
PaymentsApi
PreferencesApi
PreferencesResponse
PreferencesResponse
PreferencesResponseBuilder
PreferencesUpdate
PreferencesUpdate
PreferencesUpdateBuilder
PropelAuthWebhooksApi
SessionCreate
SessionCreate
SessionCreateBuilder
SessionListResponse
SessionListResponse
SessionListResponseBuilder
SessionResponse
SessionResponse
SessionResponseBuilder
SessionsApi
SessionType
SessionTypeMixin
Optionally, enum_class can generate a mixin to go with your enum for use with Angular. It exposes your enum constants as getters. So, if you mix it in to your Dart component class, the values become available to the corresponding Angular template.
SessionUpdate
SessionUpdate
SessionUpdateBuilder
TrataNotesClientSdk
ValidationError
ValidationError
ValidationErrorBuilder
WebhookResponse
Response schema for webhook endpoints
WebhookResponseBuilder
WebhooksApi

Extensions

DateTimeToDate on DateTime

Properties

serializers ↔ Serializers
getter/setter pair
standardSerializers ↔ Serializers
getter/setter pair