CallListResponse class abstract

Response schema for call list

Properties:

  • calls - List of calls
  • total - Total number of calls
  • page - Current page number
  • pageSize - Number of calls per page
Annotations
  • @BuiltValue.new()

Constructors

CallListResponse([void updates(CallListResponseBuilder b)])
factory

Properties

calls → BuiltList<CallStatusResponse>
List of calls
no setter
hashCode int
The hash code for this object.
no setterinherited
page int?
Current page number
no setter
pageSize int?
Number of calls per page
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of calls
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CallListResponseBuilder)) CallListResponse
Rebuilds the instance.
inherited
toBuilder() CallListResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CallListResponse>
no setter