SessionListResponseBuilder class

Properties

hashCode int
The hash code for this object.
no setterinherited
page int?
getter/setter pair
pageSize int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions ↔ ListBuilder<SessionResponse>
getter/setter pair
total int?
getter/setter pair

Methods

build() SessionListResponse
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(SessionListResponse other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(SessionListResponseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited