SessionResponse class abstract

SessionResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SessionResponse([void updates(SessionResponseBuilder b)])
factory

Properties

createdAt DateTime
Session creation timestamp
no setter
description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Session ID
no setter
insights String?
no setter
orgId String
Organization ID
no setter
recordingUrls → BuiltList<String>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionType SessionType?
no setter
summary String?
no setter
transcript String?
no setter
updatedAt DateTime
Session last update timestamp
no setter
userId String
User ID
no setter
userName String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SessionResponseBuilder)) SessionResponse
Rebuilds the instance.
inherited
toBuilder() SessionResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SessionResponse>
no setter