CallStartRequest class abstract
Request schema for starting a call
Properties:
- room - Daily.co room name
- targetNumber - Phone number to call
- provider
- metadata
- Annotations
-
- @BuiltValue.new()
Constructors
- CallStartRequest([void updates(CallStartRequestBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ BuiltMap<
String, JsonObject?> ? -
no setter
- provider → String?
-
no setter
- room → String
-
Daily.co room name
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetNumber → String
-
Phone number to call
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CallStartRequestBuilder)) → CallStartRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → CallStartRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
CallStartRequest> -
no setter